package com.qihoo.appstore.plugin.streamapp;

import com.qihoo.appstore.plugin.streamapp.IPluginHelperServiceStreamAppOnResult;

interface IPluginHelperServiceStreamApp {
	
	/**
	 * 获得接口版本号；
	 * @return
	 */
	int getVersionCode();
	
	/**
	 * 获得客户端唯一ID；
	 * @return
	 */
	String getClientId();

	/**
	 * 注册应用；
	 * @param appId
	 * @return
	 */
	boolean registerApp(String appId);
	
	/**
	 * 反注册应用；
	 * @param appId
	 * @return
	 */
	boolean unregisterApp(String appId);
	
	/**
	 * 统计-打开界面开始；
	 * @param appId
	 */
	void statOnPageStart(String appId);
	
	/**
	 * 统计-打开界面结束；
	 * @param appId
	 */
	void statOnPageEnd(String appId);
	
	/**
	 * 统计-执行动作；
	 * @param appId
	 * @param value
	 */
	void statOnEvent(String appId, String value);
	
	/**
	 * 登录（授权）
	 * @param appKey 360移动开放平台的开发者appKey；
	 * @param onResult 
	 * <pre>
	 * onResult中：
	 * 	当resultCode等于0时，resultData为json格式的token信息
	 * 	json格式：{"access_token":"用于获取用户信息","expires_in":"标识token还有多少秒过期，默认是10个小时"}；
	 * </pre>
	 */
	void login(String appKey, IPluginHelperServiceStreamAppOnResult onResult);
	
	/**
	 * 获取用户信息
	 * @param accessToken 登录（授权）后返回的access_token；
	 * @param onResult
	 * <pre>
	 * onResult中：
	 * 	当resultCode等于0时，resultData为json格式的用户信息
	 * 	json格式：{"id":"360用户ID","name":"360用户名","avatar":"360用户头像","sex":"360用户性别，返男，女或者未知","area":"360用户地区","nick":"用户昵称"}；
	 * 	当resultCode不等于0时（如：400、401等），resultMsg为json格式的错误信息，具体参见：360移动开放平台-登录服务-APIException说明文档.docx
	 * </pre>
	 */
	void getUserInfo(String accessToken, IPluginHelperServiceStreamAppOnResult onResult);
	 
    /**
     * 聚合支付,可以提供给cp使用
     * v5.0.45
     * @param json 订单信息
     *        {
     *             "pay_token":"Q9ApMjNuv4oEDERNl",
     *             "pay_seckey":"f6411c0186179c71aa9f8ffaadb11cab"
     *        }
     * @param onResult
     *
     * onResult中
     * 本地返回码：
     * -1 交易失败
     * -2 用户取消支付
     *  0 支付成功
     * -3 退出
     *
     * */
	void pay(String json, IPluginHelperServiceStreamAppOnResult onResult);

    /**
    *方法类似void pay(String json, IPluginHelperServiceStreamAppOnResult onResult);
    *只是比该方法多了个参数，区别来源
    */
	void payWithFrom(String json, String from, IPluginHelperServiceStreamAppOnResult onResult);

    /**
     * 获取设备当前位置信息，与JavaScript中的navigator.geolocation.getCurrentPosition(showPosition, showError)返回的数据对象结构是完全一致的;
     * 使用的时候，只需要将“navigator.geolocation.getCurrentPosition”替换成“XXX.getCurrentPosition”即可（只需要改前缀，后面的方法名和回调函数不变，完全兼容）；
     * 返回的数据对象与navigator.geolocation是一致的，http://dev.w3.org/geo/api/spec-source.html#position_interface；
     * 成功时的数据对象：
     * {
     *   "coords": {
     *     "latitude": 39.983421,
     *     "longitude": 116.491496,
     *     "accuracy": 150.0,
     *     "altitude": 0.0,
     *     "altitudeAccuracy": 0.0,
     *     "heading": 0.0,
     *     "speed": 0.0
     *   },
     *   "timestamp": 1435090292710,
     *   "address": {
     *     "country": "中国",
     *     "province": "北京市",
     *     "city": "北京市",
     *     "district": "朝阳区",
     *     "street": "酒仙桥路",
     *     "road": "798路",
     *     "poiName": "电子城·国际电子总部",
     *     "adCode": 110105,
     *     "cityCode": 010
     *   },
     *   "addresses": "北京市朝阳区798路靠近电子城·国际电子总部"
     * }
     *
     * 失败时的数据对象：
     * {
     *   "PERMISSION_DENIED": 1,
     *   "POSITION_UNAVAILABLE": 2,
     *   "TIMEOUT": 3,
     *   "UNKNOWN_ERROR": 4,
     *   "code": 2,
     *   "message": "获取基站/WiFi信息为空或失败"
     * }
     *
     * @param onResult
     * @param option
     *  {
     *    //指示浏览器获取高精度的位置，默认为false
     *    enableHighAcuracy: true,
     *    //指定获取地理位置的超时时间，默认不限时，单位为毫秒
     *    timeout: 5000,
     *    //最长有效期，在重复获取地理位置时，此参数指定多久再次获取位置
     *    maximumAge: 3000
     *  }
     * @param option
     */
	void getCurrentPosition(IPluginHelperServiceStreamAppOnResult onResult, String option);

	/**
	*绑定手机号码
	*onResult中：
	*resultCode=0，绑定手机号码成功;resultCode=-1,绑定失败
	*/
	void addPhoneNum(IPluginHelperServiceStreamAppOnResult onResult);

	/**
    	* 调用助手分享  从pluginhelperServiceStreamApp的version号 3 开始支持此接口。
    	* onResult中：
    	* resultCode=0，分享成功;resultCode=-1,分享失败  -3 微信没有安装或者微信不支持
    	* content 内容为json对象例如：
    	* {
    	* 	"title":"分享"
    	* 	"message":"分享内容"
    	*	"url":"http://www.so.com"  //分享的网页url
    	*   "picUrl":"http://xxx.png"//缩略图的url //值可以为 ""
    	*   "type":1/2/3  //取值范围  	public static final int SHARE_TYPE_WEIXIN_FRIEND =1;//微信好友
                                  		public static final int SHARE_TYPE_WEIXIN_TIMELINE =2;//微信朋友圈
                                  		public static final int SHARE_TYPE_WEIBO =3;//微博
        *   "from":"dcloud"  来源于哪个插件
    	* }
    	*/
    void shareToSns(IPluginHelperServiceStreamAppOnResult onResult,String content);

     /**
        * onResult 异步回调接口，可以为null
        * method  调用的方法，比如 showNotification  不能为null
        * arg  参数，可以传一些简单的参数。
        * extras  一些复杂的参数
        *
        * return bundle。一般会有两个值，一个是result 值为ok/error 。还有一个是message 值为出错的信息。可以扩展添加一些复杂的value
        */
    Bundle call(IPluginHelperServiceStreamAppOnResult onResult,String method,String arg,in Bundle extras);
}